@@ -26,7 +26,7 @@ impl<'a> Method<'a> {
     }
 
     /// Returns a reference to the inner string of the method.
-    pub fn as_str(&self) -> &str {
+    pub fn as_str(&self) -> &'a str {
         self.0
     }
 }
